# News Client (news_client)

A Drupal module which works to consume content from the news_service module.

## Notes

Originally authored by **Joe Bondra** (bondra.4@osu.edu). If any of this seems weird (and it just might) he'd probably be the one to ask...

## Dependencies

* OAuth2 Client ([oauth2_client](https://www.drupal.org/project/oauth2_client))
* Entity API ([entity](https://www.drupal.org/project/entity))
* Link ([link](https://www.drupal.org/project/link))

## Setup

### News Client (news_client)

#### OAuth2 Client configuration

There is a configuration file which should contain a JSON encoded configuration profile for the OAuth2 client. It should look something like:

```js
{
  "client_id"     : "news_client",
  "client_secret" : "<the client secret for the client id>",
  "scope"         : "news_access"
}
```

This file is consumed by the implementation of hook_oauth2_client_info in news_client.module.

On Pantheon, this file should be placed in the /private directory in the site repository.

Set up the location of this file at admin/config/services/news_client/oauth2. Enter the path of the file in the **OAuth2 Configuration File Path** field. There is an option there specifically for supporting a Pantheon binding under in the "Advanced" fieldset.

#### Settings

For the options found at admin/config/services/news_client

* **OAuth2 Server URL** - This should be the URL of the site where the news_service module is installed.
* **Service Path** - This is set by default. It will only change if something on the service side changes.
* **Update Service Path** - This is set by default.
* **Sites Service Path** - This is set by default.
* **Site Tid(s)** - You should first save all of the other settings successfully and then the Site Reference for the news service will appear below the field. Enter a comma-delimited field of tids from the table.

Be certain to save the settings before doing anything else...!

The test configuration button will make a call to the /news_service/article path on the endpoint with the provided site tids and display the results.

**NOTE** The site tid reference is cached. If you update something on the service end involving the sites taxonomy, make sure you clear the cache.

## Cache

**IMPORTANT** After setting up the module, you should do an import. See "Import" below.

All articles are imported from the service in to a Content Type called "News Client Cached Article". It's best just to leave these alone and let the module manage them.

One of the more important things in the News Client Cached Article type is the field News Service ID which contains the nid of the article on the news service.

Articles currently in the cache can be found in a convenient list at admin/config/services/news_client/cache. You can sync these individually if necessary. Only use the Sync All Articles functionality if you have a good deal of orphaned articles. It will delete these and do a full import/update of all remaining articles.

Ideally you shouldn't have to worry about the cache since articles *should be getting updated during cron using the /news_service/article_updates resource on the service endpoint*. Though, there are a lot of ways to deal with weird stuff happening using the sync and import tools.

## Import

At admin/config/services/news_client/import there are two tools.

* Import/Update Articles - allows you to import/update articles by sites defined as tids in on admin/config/services/news_client/
* Import/Update Single Article - Allows you to import/update a single article using its news service nid.

**IMPORTANT** You should run an import of all articles from the sites you added in settings. Otherwise you'll just be getting any new articles via cron, but the old articles won't show up (unless they've been updated).

## Purge

The button at admin/config/services/news_client/purge is the nuclear option for dealing with the cache. It will obliterate everything. It will probably only help in extreme circumstances and its use should be avoided...

## Tokens

News Client defines several tokens that can be used wherever necessary:

* **[node:news_client_body_summary]** Resolves to the summary of the current body of the News Client Cached Article.
* **[node:news_client_featured_image_url]** Resolves to the URL of the featured image in the News Client Cached Article.
* **[node:news_client_featured_image_alt]** Resolves to the alt text for the featured image in the News Client Cached Article.
* **[node:news_client_social_image_url]** Resolves to the URL of the social image in the News Client Cached article if set, otherwise will default to resolving to [node:news_client_featured_image_url].
* **[node:news_client_social_image_alt]** Resolves to the alt text for the social image in the News Client Cached Article. If social image isn't used then by default it resolves to [node:client_featured_image_alt].


