<?php
/**
 * Batch operations for news_client import processes.
 */

/**
 * Process a page of results from the news service.
 */
function news_client_batch_import_process_page($page_num, $per_page, $sites, $tags, &$context) {
  if (!isset($context['sandbox']['progress'])) {
    $context['sandbox']['progress'] = 0;
    $context['sandbox']['page_num'] = 1;
    $context['sandbox']['per_page'] = $per_page; 
  }
  
  // Update progress info.
  $context['sandbox']['progress']++;
  $context['message'] = t('Now processing page %page_num', array('%page_num' => $page_num));
  
  // Process page.
  $article_page = _news_client_fetch_article_page($page_num, $per_page, $sites, $tags, 0);
  
  if (!is_null($article_page) && !empty($article_page)) {
    $article_nids = $article_page['articles'];
    
    foreach ($article_nids as $nid) {
      $article = _news_client_fetch_article($nid);
      
      $cached_article = NULL;
      
      if (!is_null($article) && !empty($article)) {
        $cached_article = _news_client_cached_article_populate($article);
      }
      
      if (!is_null($cached_article)) {
        $context['results'][] = t('Import/Update complete for %nid. (%title)', array('%nid' => $nid, '%title' => $cached_article->title));
      }
      else {
        $context['results'][] = t('Import/Update failed for %nid.', array('%nid' => $nid));
      }
    }
  }
  else {
    $context['results'][] = t('Import/Update for page %page_num failed.', array('%page_num', $page_num));
  }
  
}

/**
 * Finish callback for news_client batch import.
 */
function news_client_batch_import_finished($success, $results, $operations) {
  if ($success) {
    // Here we do something meaningful with the results.
    $message = t('@count items successfully processed:', array('@count' => count($results)));
    $message .= theme('item_list', array('items' => $results));
    drupal_set_message($message);
    
    // Update last update time.
    variable_set('news_client_last_update', REQUEST_TIME);
  }
  else {
    // An error occurred.
    // $operations contains the operations that remained unprocessed.
    $error_operation = reset($operations);
    $message = t('An error occurred while processing %error_operation with arguments: @arguments', array('%error_operation' => $error_operation[0], '@arguments' => print_r($error_operation[1], TRUE)));
    drupal_set_message($message, 'error');
  }
}
